diff gen/tollvm.cpp @ 920:545f54041d91

Implemented proper support for naked asm using llvm module level asm. Still not 100% complete, but already 1000 times better that what we had before. Don's BignumX86 implementation from Tango (when turned into a standalone unittest) seems to fully work with no changes, and great performance :) Fixed align N; in asm blocks. Fixed inreg parameter passing on x86 for ref/out params. Removed support for lazy initialization of function local static variables, I have no idea why I ever implemented this, it's not in the D spec, and DMD doesn't support it :P Some of the global variable related changes might cause minor regressions, but they should be easily fixable.
author Tomas Lindquist Olsen <tomas.l.olsen@gmail.com>
date Tue, 03 Feb 2009 08:54:57 +0100
parents a4fcc13da3cd
children 39519a1ff603
line wrap: on
line diff
--- a/gen/tollvm.cpp	Mon Feb 02 02:35:44 2009 +0100
+++ b/gen/tollvm.cpp	Tue Feb 03 08:54:57 2009 +0100
@@ -294,8 +294,9 @@
         if (fdecl->llvmInternal == LLVMintrinsic)
             return llvm::GlobalValue::ExternalLinkage;
         // template instances should have weak linkage
-        // but only if there's a body, otherwise we make it external
-        else if (DtoIsTemplateInstance(fdecl) && fdecl->fbody)
+        // but only if there's a body, and it's not naked
+        // otherwise we make it external
+        else if (DtoIsTemplateInstance(fdecl) && fdecl->fbody && !fdecl->naked)
             return TEMPLATE_LINKAGE_TYPE;
         // extern(C) functions are always external
         else if (ft->linkage == LINKc)